from django.contrib.flatpages.models import FlatPage
from django.db import models
from django.contrib.sites.models import Site
from django.utils.translation import ugettext_lazy as _

class CMSFlatPage(FlatPage):
    description = models.CharField(verbose_name=_(u"Description"),max_length=100)
    keywords = models.CharField(verbose_name=_(u"Keywords"),max_length=255)


# -*- coding: utf-8 -*-
import os.path
from setuptools import setup


def get_source_files():
    for dirname, _, files in os.walk('ckeditor/static/ckeditor/ckeditor/_source'):
        for filename in files:
            yield os.path.join('/'.join(dirname.split('/')[1:]), filename)

setup(
    name='django-extended-flatpages',
    version='0.1',
    packages = ['extended_flatpages'],
    include_package_data = True,
    license = 'Apache License, Version 2.0', 
    description='Django flatpages CKEditor integration and SEO values.',
    long_description=open('README.md', 'r').read() + open('AUTHORS.md', 'r').read() + open('CHANGELOG.md', 'r').read(),
    url='https://github.com/hisie/django_extended_flatpages',
    author='hisie',
    author_email='dcebrian@serincas.com',
    install_requires=[
        'django-ckeditor',
    ],
    exclude_package_data={
        'ckeditor': list(get_source_files()),
    },
    test_suite="setuptest.setuptest.SetupTestSuite",
    tests_require=[
        'django-setuptest>=0.1.1',
    ],
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: BSD License",
        "Development Status :: 4 - Beta",
        "Operating System :: OS Independent",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
)



# -*- coding: utf-8 -*-
from django.contrib import admin
# Original flatpages admin
from models import CMSFlatPage 
from django.contrib.flatpages.models import FlatPage
from django.contrib.flatpages.admin import FlatPageAdmin
from django.contrib.flatpages.admin import FlatpageForm
# For translation
from django.conf import settings
# For CKEditor
from django import forms
from ckeditor.widgets import CKEditorWidget
from django.utils.translation import ugettext_lazy as _

class CustomFlatpageForm(FlatpageForm):
    locals()['content'] = forms.CharField(widget=CKEditorWidget(), required=False, label=_(u'Content'))
    description = forms.CharField(required=False, label=_(u'Description'))
    keywords = forms.CharField(required=False, label=_(u'Keywords'))
    
    class Meta:
        model = CMSFlatPage

class CustomFlatPageAdmin(FlatPageAdmin): 
    form = CustomFlatpageForm
    fieldsets = (
        (None, {'fields': ('url', 'title', 'content', 'sites', 'keywords', 'description')}),
        (_('Advanced options'), {'classes': ('collapse',), 'fields': ('enable_comments', 'registration_required', 'template_name')}),
    )
    class Media:
        js = (
            'js/jquery.min.js',
            'js/jquery-ui.min.js',
        )

admin.site.unregister(FlatPage) 
admin.site.register(CMSFlatPage, CustomFlatPageAdmin)